<?php

namespace Spocket\ActivationCheck;

class Requirements {

	private static $object = null;

	/**
	 * The plugin instance.
	 *
	 * @var Plugin
	 */
	private $plugin;

	/**
	 * The response instance.
	 *
	 * @var response
	 */
	private $response;

	/**
	 * Verify if the request to Spocket server is failing
	 *
	 * @return bool
	 */
	private function willRequestFail() {
		$this->response = wp_safe_remote_get(
			$this->plugin->getApiURL(),
			array(
				'timeout' => 15
			)
		);

		if (is_wp_error($this->response)) {
			return true;
		}

		return false;
	}

	/**
	 * Verify if WooCommerce is installed and activated.
	 *
	 * @return bool
	 */
	private function isWoocommerceActivated() {
		if (in_array('woocommerce/woocommerce.php', apply_filters('activate_plugins', get_option('active_plugins')))) {
			return true;
		}

		return false;
	}

	/**
	 * Disable plugin.
	 *
	 * @return void
	 */
	private function deactivateSpocketPlugin() {
		if (current_user_can('activate_plugins') && is_plugin_active(self::$object->plugin->getPluginBaseName())) {
			deactivate_plugins(plugin_basename(self::$object->plugin->getPluginBaseName()));
			if ( isset( $_GET['activate'] ) ) {
				unset( $_GET['activate'] );
			}
		}
	}

	/**
	 * Sets up initial instance properties
	 *
	 * @param \Spocket\Plugin $plugin This plugin's instance.
	 * @return void
	 */
	public function __construct( \Spocket\Plugin $plugin) {
		self::$object = $this;
		$this->plugin = $plugin;
	}

	/**
	 * Disable the plugin if the request fails.
	 *
	 * @return void
	 */
	public static function disablePluginIfRequirementsFail() {
		if (!getenv('IS_DEV') && self::$object->willRequestFail()) {
			add_action(
				'admin_notices',
				self::$object->notifyUser('The Spocket plugin cannot be activated as your server is blocking the request. Please contact your hosting service.', self::$object->response->get_error_message())
			);

			self::$object->deactivateSpocketPlugin();
		} elseif (!self::$object->isWoocommerceActivated()) {
			self::$object->deactivateSpocketPlugin();
			wp_die(esc_html__('Sorry, WooCommerce needs to be installed before you can activate Spocket. <a href="javascript:history.back()">Back to Plugins page.</a>'));

		}
	}

	/**
	 * Shows up a notice error message on WordPress Dashboard.
	 *
	 * @param string $title The message's title
	 * @param string $message the message itself
	 *
	 * @return void
	 */
	public static function notifyUser( $title, $message) {
		?>
			<div class='error woocommerce-message'>
			  <p>
				<?php echo esc_html__($title); ?>
			  </p>
			  <p>
				<b>Error: </b><?php echo esc_html__($message); ?>
			  </p>
			</div>
		<?php
	}

	/**
	 * Runs the requirements.
	 *
	 * @return void
	 */
	public function run() {
		add_action('admin_init', array($this, 'disablePluginIfRequirementsFail'));
	}

}
